@@ -23,7 +23,7 @@
 # WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 # FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 # OTHER DEALINGS IN THE SOFTWARE.
-version = '0.5.2'
+version = '0.5.3'
 
 import re
 import socket
@@ -196,11 +196,11 @@ class fakesock(object):
         def _true_sendall(self, data, *args, **kw):
             self.truesock.connect(self._address)
             self.truesock.sendall(data, *args, **kw)
-            _d = self.truesock.recv(255)
+            _d = self.truesock.recv(16)
             self.fd.seek(0)
             self.fd.write(_d)
             while _d:
-                _d = self.truesock.recv(255)
+                _d = self.truesock.recv(16)
                 self.fd.write(_d)
 
             self.fd.seek(0)
@@ -297,6 +297,7 @@ def fake_getaddrinfo(
 STATUSES = {
     100: "Continue",
     101: "Switching Protocols",
+    102: "Processing",
     200: "OK",
     201: "Created",
     202: "Accepted",
@@ -304,13 +305,18 @@ STATUSES = {
     204: "No Content",
     205: "Reset Content",
     206: "Partial Content",
+    207: "Multi-Status",
+    208: "Already Reported",
+    226: "IM Used",
     300: "Multiple Choices",
     301: "Moved Permanently",
     302: "Found",
     303: "See Other",
     304: "Not Modified",
     305: "Use Proxy",
+    306: "Switch Proxy",
     307: "Temporary Redirect",
+    308: "Permanent Redirect",
     400: "Bad Request",
     401: "Unauthorized",
     402: "Payment Required",
@@ -319,22 +325,51 @@ STATUSES = {
     405: "Method Not Allowed",
     406: "Not Acceptable",
     407: "Proxy Authentication Required",
-    408: "Request Time-out",
+    408: "Request a Timeout",
     409: "Conflict",
     410: "Gone",
     411: "Length Required",
     412: "Precondition Failed",
     413: "Request Entity Too Large",
-    414: "Request-URI Too Large",
+    414: "Request-URI Too Long",
     415: "Unsupported Media Type",
-    416: "Requested range not satisfiable",
+    416: "Requested Range Not Satisfiable",
     417: "Expectation Failed",
+    418: "I'm a teapot",
+    420: "Enhance Your Calm",
+    422: "Unprocessable Entity",
+    423: "Locked",
+    424: "Failed Dependency",
+    424: "Method Failure",
+    425: "Unordered Collection",
+    426: "Upgrade Required",
+    428: "Precondition Required",
+    429: "Too Many Requests",
+    431: "Request Header Fields Too Large",
+    444: "No Response",
+    449: "Retry With",
+    450: "Blocked by Windows Parental Controls",
+    451: "Unavailable For Legal Reasons",
+    451: "Redirect",
+    494: "Request Header Too Large",
+    495: "Cert Error",
+    496: "No Cert",
+    497: "HTTP to HTTPS",
+    499: "Client Closed Request",
     500: "Internal Server Error",
     501: "Not Implemented",
     502: "Bad Gateway",
     503: "Service Unavailable",
-    504: "Gateway Time-out",
-    505: "HTTP Version not supported",
+    504: "Gateway Timeout",
+    505: "HTTP Version Not Supported",
+    506: "Variant Also Negotiates",
+    507: "Insufficient Storage",
+    508: "Loop Detected",
+    509: "Bandwidth Limit Exceeded",
+    510: "Not Extended",
+    511: "Network Authentication Required",
+    598: "Network read timeout error",
+    599: "Network connect timeout error",
 }
 
 
